function [dft_freq, dft_pow] = do_sim(vecs)

% [dft_freq, dft_pow] = do_sim(vecs)
%
% Run a simulation of the distributional semantics model for cortical entrainment, 
% on a sequence of stimuli represented by vectors
%
% vecs{s,i}   : Input column vectors for simulated subject s and sentence i,
%               with sentences in random order per subject
% 
% Outputs:
% dft_freq     : Frequency vectors from Fourier transformation.
% dft_pow(f,s) : Power at frequency dft_freq(f) according to Discrete Fourier Transformation
%                on the sequence of word vectors; averaged over DFTs for each vector dimension 

% Set parameters
samp_freq   = 200;          % simulated sampling frequency (Hz)
SOA         = 250;          % number of simulated ms between inputs
noise       = 0.5;          % standard deviation of gaussian noise added to vectors
start_mean  = 40;           % mean (in simulated ms) of uniform distribution for arrival of lexical information
start_width = 50;           % width (in simulated ms) of uniform distribution for arrival of lexical information

% Initialize variables
vecs          = rm_nan(vecs);              % remove sentences than contain any NaN
[Nsubj,Nsent] = size(vecs);                % number of simulated subjects and sentence stimuli
Nstim         = size(cell2mat(vecs),2);    % number of input tokens in all sentence stimuli combined
NsampSOA      = samp_freq*SOA/1000;        % number of samples per SOA
Nsamp         = NsampSOA*Nstim;            % number of samples over the entire presentation sequence

dft_pow = zeros((2^nextpow2(Nsamp))/2+1,Nsubj);    % Initialize power spectra matrix for subjects

for subj_nr = 1:Nsubj
    
    subj_vecs = vecs(subj_nr,:);   
    stim      = cell2mat(subj_vecs);                           % sentences concatenated into one matrix
    Ndim      = size(cell2mat(subj_vecs),1);                   % vector dimensionality
    dim_pow   = zeros(Ndim,(2^nextpow2(Nsamp))/2+1);           % Initialize power spectra matrix for all dimensions

    % Concatenate word vectors into time-sequence matrices
    X = zeros(Ndim,Nsamp);    
    for i = 1:Nstim
        
        start     = start_mean + start_width*(rand-.5);        % vector arrives at 'this_start_mean' ms plus uniform noise
        start_idx = max(round(start*samp_freq/1000),1);        % round arrival index to positive integer

        % fill samples for current stimulus item with the current vector,
        % but leave values 0 up to start_idx
        if start_idx <= NsampSOA
            fillrange      = (i-1)*NsampSOA+start_idx:i*NsampSOA;
            X(:,fillrange) = repmat(stim(:,i),1,length(fillrange));
        end
    end
    
    X = X + noise*randn(size(X));   % add noise 

    % Do FFT on each vector dimension individually
    for i = 1:Ndim
        [dft_freq, dim_pow(i,:)] = do_fft(X(i,:), samp_freq);
    end

    dft_pow(:,subj_nr) = 20*log10(mean(dim_pow,1));   % Average over dimensions and convert to decibel scale
end

% Remove frequencies >5 Hz
max_freq_idx = find(dft_freq>5,1)-1;
dft_pow      = dft_pow(1:max_freq_idx,:);
dft_freq     = dft_freq(1:max_freq_idx);
