function h = plot_pow(dft_freq, dft_pow, se, sign, minfreq, maxfreq, freqstep, bottom, top)

% h = plot_pow_sign(dft_freq, dft_pow, se, sign, minfreq, maxfreq, freqstep, bottom, top)
%
% Plot power spectum and return handle to line for average over subjects.
%
% dft_freq, dft_pow  : output of do_sim.m (frequency points in spectrum and their power)
% se                 : set to 1 to show SE over subjects as shaded area, otherwise (default)
%                      shows individual subjects as grey lines
% sign               : set to 1 to run significance test and plot * over significant peaks
% minfreq, maxfreq   : lower and upper end of plotted frequency range.
%                      Default: 6/9 Hz and 41/9 Hz (which Ding et al., 2016, use for Chinese.
%                      For English: 7/11 and 50/11).
%                      NOTE: If sign==1, dtf_freq must include 2*freqstep below minfreq and
%                      above maxfreq, because the power at these frequencies are used as baseline
%                      to determine peak size.
% freqstep           : resolution of plotted frequency axis. Default: 1/9 Hz (for English, use 1/11)
%                      If the frequencies of interest are not in [minfreq:freqstep:maxfreq],
%                      the nearest frequencies are used.
% bottom, top        : lower and upper bound on y-axis. Default: extreme values +/-10% 

if nargin < 7; freqstep =  1/9; end
if nargin < 6; maxfreq  = 41/9; end
if nargin < 5; minfreq  =  6/9; end
if nargin < 4; sign     = 0; end
if nargin < 3; se       = 0; end

Nsubj  = size(dft_pow,2);
% Find the indices of dft_freq closest to the frequencies of interest
if sign == 1
    foi = (minfreq-2*freqstep):freqstep:(maxfreq+2*freqstep);
else
    foi = minfreq:freqstep:maxfreq;
end

xrange = nan(1,length(foi));
for f = 1:length(foi)
    x = find(dft_freq == foi(f));
    if ~isempty(x)      % this frequency of interest is present in dft_freq
        xrange(f) = x;
    else                % find the frequency closest to this frequency of interest
        max_x = find(dft_freq > foi(f),1,'first');
        min_x = find(dft_freq < foi(f),1,'last');
        if abs(dft_freq(max_x)-foi(f)) < abs(dft_freq(min_x)-foi(f))
            xrange(f) = max_x;
        else
            xrange(f) = min_x;
        end
    end
end
freqs  = dft_freq(xrange);

if Nsubj > 1
    pows     = dft_pow(xrange,:);
    mean_pow = mean(pows,2)';
    serr     = std(pows,[],2)'/sqrt(Nsubj);
else
    mean_pow = dft_pow(xrange);
end

hold on

if Nsubj > 1
    if se == 0
        for i = 1:Nsubj
            plot(freqs, pows(:,i),'color',[.7 .7 .7])
        end
    else
        fill([freqs freqs(end:-1:1)],[mean_pow-serr mean_pow(end:-1:1)+serr(end:-1:1)],[170/255 170/255 1],'linestyle','none')
    end
end
h = plot(freqs, mean_pow,'color',[0 0 1]);
set(h,'linewidth',1)
if nargin < 9
    vscale = .4;
    if Nsubj == 1
        top    = max(mean_pow)+vscale*(max(mean_pow)-min(mean_pow));
        bottom = min(mean_pow)-2;
    else
        if se == 1
            top    = max(mean_pow+serr)+vscale*(max(mean_pow+serr)-min(mean_pow-serr));
            bottom = min(mean_pow-serr)-vscale*(max(mean_pow+serr)-min(mean_pow-serr))+5;
        else
            top    = max(max(pows))+vscale*(max(max(pows))-min(min(pows)));
            bottom = min(min(pows))-vscale*(max(max(pows))-min(min(pows)))+2;
        end
    end
end

box on
axis([minfreq maxfreq bottom top])
set(gca,'xtick',1:4)
set(gca,'ytick',[])
% xlabel('Frequency (Hz)')
% ylabel('Power')

dbscale = 5*round((top-bottom)/25);
plot([minfreq+.5 minfreq+.5],[bottom+.5*dbscale bottom+1.5*dbscale],'k-')
text(minfreq+.6,bottom+.5*dbscale,[num2str(dbscale) ' dB'],'fontsize',9,'verticalalignment','bottom')

if sign == 1
    %--------------------------------------------------------------------------
    % For each frequency point in xrange, test whether its power is significantly above
    % the average at the previous two and current two points (cf. Ding et al., 2016).
    % Then do Benjamini & Hochberg's (1995) FDR correction and plot a * above
    % each peak that survives the correction.

    pval = zeros(1,length(xrange)-5);
    for x = 3:length(xrange)-2
       [h,pval(x-2)] = ttest(dft_pow(xrange(x),:)',mean(dft_pow(xrange(x+[-2 -1 1 2]),:))',.05,'right');   % one-tailed t-test because we only care about power that is higher than its neighbours. 
    end

    sign_ind = 2+benjamini(pval,.025);     % indices of xrange where power is significantly stronger than at neighbouring points. Set alpha to .025 to compensate for one-tailed testing.
    text(dft_freq(xrange(sign_ind)), mean(dft_pow(xrange(sign_ind),:),2)+dbscale/3,'*','horizontalalignment','center','fontsize',12);
end